# latexify_py
A Python package that generates LaTeX math description from Python functions.

## FAQs
1. Which Python version? ... Using 3.10 AST.
2. GPT-3? ... No, rule-based.

## Installation

```shell
pip install latexify-py
```

## Example

Follow provided example on [Google Colaboratory](https://colab.research.google.com/drive/1MuiawKpVIZ12MWwyYuzZHmbKThdM5wNJ?usp=sharing).

## How to Contribute 
To contribute to this Project refer [CONTRIBUTING.md](https://github.com/google/latexify_py/blob/develop/CONTRIBUTING.md) file.

## Disclaimer

This is not an officially supported Google product.

## License 

This Repository follows [Apache License 2.0](https://github.com/google/latexify_py/blob/develop/LICENSE).
